local FC = ...

local comList = {"BEER","BERRIES","BREAD","BOAR","CHEESE","CLOTHES","FISH","GOLD","HERBS","HONEY","MEAL","SPEAR","SWORD","WINE"}
local conList = {"GLASS","MARBLE","PLANK","POLISHED_STONE","STONE","TOOL","WOOD","WOOLEN_CLOTH"}
local rawList = {"BARREL","COAL","FLOUR","GRAPES","HEMP","HOP","IRON","IRON_ORE","LEATHER","MILK","QUARTZ","WHEAT","WOOL"}
local percList = {0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,1,1.1,1.2,1.3,1.4,1.5,1.6,1.7,1.8,1.9,2,5,10}


local function QuestRewardResources(resources)
	return {
		DataType = "QUEST_REWARD_RESOURCES",
		ResourceCollection = resources
	}
end

local function QuestRewardHappy(percent, duration)
	return {
		DataType = "QUEST_REWARD_GAME_RULE",
		RuleModifier = {
			DataType = "GAME_RULE_MODIFIER_HAPPINESS",
			Name = "GAME_RULE_MODIFIER_HAPPINESS_NAME",
			IsUntilRemoval = false,
			BonusHappinessPercentage = percent,
			DurationInDays = duration
		}
	}
end

local function QuestRewardJob(percent, duration)
	return {
		DataType = "QUEST_REWARD_GAME_RULE",
		RuleModifier = {
			DataType = "GAME_RULE_MODIFIER_JOB_LEARNING_SPEED",
			Name = "GAME_RULE_MODIFIER_JOB_LEARNING_SPEED_NAME",
			IsUntilRemoval = false,
			XPBonusPercentage = percent,
			DurationInDays = duration
		}
	}
end

local function QuestRewardMilitary(percent, duration)
	return {
		DataType = "QUEST_REWARD_GAME_RULE",
		RuleModifier = {
			DataType = "GAME_RULE_MODIFIER_MILITARY_TRAINING",
			Name = "GAME_RULE_MODIFIER_MILITARY_TRAINING_NAME",
			IsUntilRemoval = false,
			XPBonusPercentage = percent,
			DurationInDays = duration
		}
	}
end

local function QuestRewardCrop(percent, duration,list)
	return {
		DataType = "QUEST_REWARD_GAME_RULE",
		RuleModifier = {
			DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
			Name = "GAME_RULE_MODIFIER_CROP_YIELDS_NAME",
			IsUntilRemoval = false,
			YieldPercentage = percent,
			DurationInDays = duration,
			ResourceList = list
		}
	}
end

local function QuestRewardTrade(percent, duration)
	return {
		DataType = "QUEST_REWARD_GAME_RULE",
		RuleModifier = {
			DataType = "GAME_RULE_MODIFIER_TRADE_BONUS",
			Name = "GAME_RULE_MODIFIER_TRADE_BONUS_NAME",
			IsUntilRemoval = false,
			BonusRevenuePercentage = percent,
			DurationInDays = duration,
			EstateAllegianceList = {"LABOUR","CLERGY","KINGDOM"}
		}
	}
end

local function QuestFunctionDelivery(resources)
	return {
		DataType = "QUEST_FUNCTION_DELIVER_RESOURCES",
		ResourceListToDeliver = resources,
		Estate = "CLERGY",
		DaysCount = 10000000
	}
end

local function QuestFunctionBuild(BuildingList)
	return {
		DataType = "QUEST_FUNCTION_BUILD",
		BuildingListToBuild = BuildingList
	}
end

local function QuestRewardInfluence(influence)
	return {
		DataType = "QUEST_REWARD_INFLUENCE",
		EstateInfluence = influence
	}
end

local function QuestRewardMarket(perc,duration)
	return {
		DataType = "QUEST_REWARD_MARKET_PRICES",
		PriceBonuses = perc,
		DurationInDays = duration
	}
end

FC:register({
	DataType = "QUEST",
	Id = "INFINITE_RESOURCES_QUEST",
	Name = "INFINITE_RESOURCES_QUEST_NAME",
	Description = "INFINITE_RESOURCES_QUEST_DESC",
	QuestFunction = QuestFunctionDelivery({{Resource = "BERRIES", Quantity = 1}}),	
	QuestRewardList = {
		QuestRewardResources({{Resource = "BERRIES", Quantity = 1}}),
	},
	QuestListToUnlockAfter = {{QuestResource = "INFINITE_RESOURCES_QUEST", Delay = 0}},
	OnSuccessCallback = {

		DataType = "EVENT_CALLBACK_TRIGGER_EVENT", 
		Event = "INFINITE_RESOURCES_EVENT", 
		Delay = 0

	} 
})

FC:register({
	DataType = "EVENT",
	Id = "INFINITE_RESOURCES_EVENT",
	Title = "INFINITE_RESOURCES_EVENT_TITLE",
	Description = "INFINITE_RESOURCES_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = {
		{
			ShortName = "FE_RESOURCES_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_RESOURCES_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_WEATHER_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_WEATHER_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_INFLUENCE_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_INFLUENCE_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
--[[
		{
			ShortName = "FE_GAMERULE_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
--]]
		{
			ShortName = "FE_EXIT_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE"
				}
			}
		},
	}
})

FC:register({
	DataType = "EVENT",
	Id = "FE_WEATHER_MAIN_EVENT",
	Title = "FE_WEATHER_MAIN_EVENT_TITLE",
	Description = "FE_WEATHER_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = {
		{
			ShortName = "FE_SUNNY_ACCEPT",
			EventActionList = {	
				{
					DataType = "EVENT_ACTION_CHANGE_WEATHER",
					AssetWeather = "WEATHER_SUNNY"
				
				}
			}
		},
		{
			ShortName = "FE_RAINY_ACCEPT",
			EventActionList = {	
				{
					DataType = "EVENT_ACTION_CHANGE_WEATHER",
					AssetWeather = "WEATHER_RAINY"
					
				}
			}
		},
		{
			ShortName = "FE_STORM_ACCEPT",
			EventActionList = {	
				{
					DataType = "EVENT_ACTION_CHANGE_WEATHER",
					AssetWeather = "WEATHER_STORM"
					
				}
			}
		},
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "INFINITE_RESOURCES_EVENT",
						Delay = 0
					}
				}
			}
		},
	}
})

FC:register({
	DataType = "EVENT",
	Id = "FE_INFLUENCE_MAIN_EVENT",
	Title = "FE_INFLUENCE_MAIN_EVENT_TITLE",
	Description = "FE_INFLUENCE_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = {
		{
			ShortName = "FE_CLERGY_ACCEPT",
			EventActionList = {
				{	
					DataType = "EVENT_ACTION_GIVE_REWARD",
					QuestRewardList = {
						QuestRewardInfluence({Estate = "CLERGY", Quantity = 20})
					},
				}
			}
		},
		{
			ShortName = "FE_KINGDOM_ACCEPT",
			EventActionList =  {
				{	
					DataType = "EVENT_ACTION_GIVE_REWARD",
					QuestRewardList = {
						QuestRewardInfluence({Estate = "KINGDOM", Quantity = 20})
					},
				}
			}
		},
		{
			ShortName = "FE_LABOUR_ACCEPT",
			EventActionList =  {
				{	
					DataType = "EVENT_ACTION_GIVE_REWARD",
					QuestRewardList = {
						QuestRewardInfluence({Estate = "LABOUR", Quantity = 20})
					},
				}
			}
		},
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "INFINITE_RESOURCES_EVENT",
						Delay = 0
					}
				}
			}
		},
	}
})

FC:register({
	DataType = "EVENT",
	Id = "FE_GAMERULE_MAIN_EVENT",
	Title = "FE_GAMERULE_MAIN_EVENT_TITLE",
	Description = "FE_GAMERULE_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = {
		{
			ShortName = "FE_GAMERULE_HAPPINESS_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_HAPPINESS_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_GAMERULE_JOB_SPEED_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_JOB_SPEED_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_GAMERULE_MILITARY_SPEED_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_MILITARY_SPEED_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_GAMERULE_CROP_YIELDS_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_CROP_YIELDS_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_GAMERULE_TRADE_BONUS_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_TRADE_BONUS_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_GAMERULE_MARKET_PRICE_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_MARKET_PRICE_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "INFINITE_RESOURCES_EVENT",
						Delay = 0
					}
				}
			}
		},
	}
})

local function buildHappyChoices ()
	local list = {}
	local i = 1
	for k,v in pairs(percList) do
		list[i] = 
		{
			ShortName = "FE_"..v.."_ACCEPT",
			EventActionList = {
				{	
					DataType = "EVENT_ACTION_GIVE_REWARD",
					QuestRewardList = {
						QuestRewardHappy(v,100)
					},
				}
			}
		}
		i = i +1
	end
	list[i] = 
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		}
	return list
end

FC:register({
	DataType = "EVENT",
	Id = "FE_GAMERULE_HAPPINESS_EVENT",
	Title = "FE_GAMERULE_HAPPINESS_EVENT_TITLE",
	Description = "FE_GAMERULE_HAPPINESS_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildHappyChoices ()
})

local function buildTradeChoices ()
	local list = {}
	local i = 1
	for k,v in pairs(percList) do
		list[i] = 
		{
			ShortName = "FE_"..v.."_ACCEPT",
			EventActionList = {
				{	
					DataType = "EVENT_ACTION_GIVE_REWARD",
					QuestRewardList = {
						QuestRewardTrade(v,100)
					},
				}
			}
		}
		i = i +1
	end
	list[i] = 
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		}
	return list
end

FC:register({
	DataType = "EVENT",
	Id = "FE_GAMERULE_TRADE_BONUS_EVENT",
	Title = "FE_GAMERULE_TRADE_BONUS_EVENT_TITLE",
	Description = "FE_GAMERULE_TRADE_BONUS_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildTradeChoices ()
})

local function buildMarketChoices ()
	local list = {}
	local i = 1
	for k,v in pairs(percList) do
		list[i] = 
		{
			ShortName = "FE_"..v.."_ACCEPT",
			EventActionList = {
				{	
					DataType = "EVENT_ACTION_GIVE_REWARD",
					QuestRewardList = {
						QuestRewardMarket(v,100)
					},
				}
			}
		}
		i = i +1
	end
	list[i] = 
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		}
	return list
end

FC:register({
	DataType = "EVENT",
	Id = "FE_GAMERULE_MARKET_PRICE_EVENT",
	Title = "FE_GAMERULE_MARKET_PRICE_EVENT_TITLE",
	Description = "FE_GAMERULE_MARKET_PRICE_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildMarketChoices ()
})

local function buildJobChoices ()
	local list = {}
	local i = 1
	for k,v in pairs(percList) do
		list[i] = 
		{
			ShortName = "FE_"..v.."_ACCEPT",
			EventActionList = {
				{	
					DataType = "EVENT_ACTION_GIVE_REWARD",
					QuestRewardList = {
						QuestRewardJob(v,100)
					},
				}
			}
		}
		i = i +1
	end
	list[i] = 
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		}
	return list
end

FC:register({
	DataType = "EVENT",
	Id = "FE_GAMERULE_JOB_SPEED_EVENT",
	Title = "FE_GAMERULE_JOB_SPEED_EVENT_TITLE",
	Description = "FE_GAMERULE_JOB_SPEED_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildJobChoices()
})

local function buildMilitaryChoices ()
	local list = {}
	local i = 1
	for k,v in pairs(percList) do
		list[i] = 
		{
			ShortName = "FE_"..v.."_ACCEPT",
			EventActionList = {
				{	
					DataType = "EVENT_ACTION_GIVE_REWARD",
					QuestRewardList = {
						QuestRewardMilitary(v,100)
					},
				}
			}
		}
		i = i +1
	end
	list[i] = 
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		}
	return list
end

FC:register({
	DataType = "EVENT",
	Id = "FE_GAMERULE_MILITARY_SPEED_EVENT",
	Title = "FE_GAMERULE_MILITARY_SPEED_EVENT_TITLE",
	Description = "FE_GAMERULE_MILITARY_SPEED_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildMilitaryChoices()
})

FC:register({
	DataType = "EVENT",
	Id = "FE_GAMERULE_CROP_YIELDS_MAIN_EVENT",
	Title = "FE_GAMERULE_CROP_YIELDS_MAIN_EVENT_TITLE",
	Description = "FE_GAMERULE_CROP_YIELDS_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = {
		{
			ShortName = "FE_COMMODITY_RESOURCES_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_CROP_YIELDS_COMMODITY_RESOURCES_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_CONSTRUCTION_RESOURCES_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_CROP_YIELDS_CONSTRUCTION_RESOURCES_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_RAW_RESOURCES_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_CROP_YIELDS_RAW_RESOURCES_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
	}
})


local function buildCropChoices (x)
	local list = {}
	local i = 1
	for k,v in pairs(percList) do
		list[i] = 
		{
			ShortName = "FE_"..v.."_ACCEPT",
			EventActionList = {
				{	
					DataType = "EVENT_ACTION_GIVE_REWARD",
					QuestRewardList = {
						QuestRewardCrop(v,100,{x})
					},
				}
			}
		}
		i = i +1
	end
	list[i] = 
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_GAMERULE_CROP_YIELDS_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		}
	return list
end

function buildGameruleResourceEventList(list)
	local result = {}
	for k,v in pairs(list) do
		FC:register({
			DataType = "EVENT",
			Id = "FE_GAMERULE_CROP_YIELDS_"..v.."_EVENT",
			Title = "FE_GAMERULE_CROP_YIELDS_MAIN_EVENT_TITLE",
			Description = "FE_GAMERULE_CROP_YIELDS_RESOURCE_EVENT_DESC",
			PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
			Delay = 0,
			ConditionList = {
				{
				DataType = "EVENT_CONDITION_BUILDING_BUILT",
				AssetBuilding = "BUILDING_VILLAGE_CENTER"
				}
			},
			ChoiceList = buildCropChoices(v)
		})
	end
end

function buildGameruleResourceButtonList(list)
	local result = {}
	local i = 1
	for k,v in pairs(list) do
		result[i] = 
			{
				ShortName = "FE_"..v.."_ACCEPT",
				EventActionList = {
					{
						DataType = "EVENT_ACTION_IGNORE",
						OnClickCallback = {
							DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
							Event = "FE_GAMERULE_CROP_YIELDS_"..v.."_EVENT",
							Delay = 0
						}
					}
				}
			}
		i = i+1
	end
	result[i] = 		
	{
		ShortName = "FE_BACK_ACCEPT",
		EventActionList = {
			{
				DataType = "EVENT_ACTION_IGNORE",
				OnClickCallback = {
					DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
					Event = "FE_GAMERULE_CROP_YIELDS_MAIN_EVENT",
					Delay = 0
				}
			}
		}
	}
	i = nill
	return result
end

buildGameruleResourceEventList(rawList)
buildGameruleResourceEventList(comList)
buildGameruleResourceEventList(conList)

FC:register({
	DataType = "EVENT",
	Id = "FE_GAMERULE_CROP_YIELDS_COMMODITY_RESOURCES_MAIN_EVENT",
	Title = "FE_GAMERULE_CROP_YIELDS_MAIN_EVENT_TITLE",
	Description = "FE_GAMERULE_CROP_YIELDS_RESOURCES_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildGameruleResourceButtonList(comList)
})

FC:register({
	DataType = "EVENT",
	Id = "FE_GAMERULE_CROP_YIELDS_RAW_RESOURCES_MAIN_EVENT",
	Title = "FE_GAMERULE_CROP_YIELDS_MAIN_EVENT_TITLE",
	Description = "FE_GAMERULE_CROP_YIELDS_RESOURCES_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildGameruleResourceButtonList(rawList)
})

FC:register({
	DataType = "EVENT",
	Id = "FE_GAMERULE_CROP_YIELDS_CONSTRUCTION_RESOURCES_MAIN_EVENT",
	Title = "FE_GAMERULE_CROP_YIELDS_MAIN_EVENT_TITLE",
	Description = "FE_GAMERULE_CROP_YIELDS_RESOURCES_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildGameruleResourceButtonList(conList)
})










FC:register({
	DataType = "EVENT",
	Id = "FE_RESOURCES_MAIN_EVENT",
	Title = "FE_RESOURCES_MAIN_EVENT_TITLE",
	Description = "FE_RESOURCES_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = {
		{
			ShortName = "FE_COMMODITY_RESOURCES_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_COMMODITY_RESOURCES_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_CONSTRUCTION_RESOURCES_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_CONSTRUCTION_RESOURCES_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_RAW_RESOURCES_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "FE_RAW_RESOURCES_MAIN_EVENT",
						Delay = 0
					}
				}
			}
		},
		{
			ShortName = "FE_BACK_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_IGNORE",
					OnClickCallback = {
						DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
						Event = "INFINITE_RESOURCES_EVENT",
						Delay = 0
					}
				}
			}
		},
	}
})

function buildResourceButtonList(list)
	local result = {}
	local i = 1
	for k,v in pairs(list) do
		result[i] = 
		{
			ShortName = "FE_"..v.."_ACCEPT",
			EventActionList = {
				{
					DataType = "EVENT_ACTION_GIVE_REWARD",
					QuestRewardList = {QuestRewardResources({
						{Resource = v, Quantity = 1000}
					})}
				}
			}
		}
		i = i +1
	end
	result[i] = 		
	{
		ShortName = "FE_BACK_ACCEPT",
		EventActionList = {
			{
				DataType = "EVENT_ACTION_IGNORE",
				OnClickCallback = {
					DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
					Event = "FE_RESOURCES_MAIN_EVENT",
					Delay = 0
				}
			}
		}
	}
	i = nill
	return result
end

FC:register({
	DataType = "EVENT",
	Id = "FE_COMMODITY_RESOURCES_MAIN_EVENT",
	Title = "FE_RESOURCES_MAIN_EVENT_TITLE",
	Description = "FE_PICK_RESOURCES_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildResourceButtonList(comList)
})

FC:register({
	DataType = "EVENT",
	Id = "FE_RAW_RESOURCES_MAIN_EVENT",
	Title = "FE_RESOURCES_MAIN_EVENT_TITLE",
	Description = "FE_PICK_RESOURCES_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildResourceButtonList(rawList)
})

FC:register({
	DataType = "EVENT",
	Id = "FE_CONSTRUCTION_RESOURCES_MAIN_EVENT",
	Title = "FE_RESOURCES_MAIN_EVENT_TITLE",
	Description = "FE_PICK_RESOURCES_MAIN_EVENT_DESC",
	PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
	Delay = 0,
	ConditionList = {
		{
		DataType = "EVENT_CONDITION_BUILDING_BUILT",
		AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ChoiceList = buildResourceButtonList(conList)
})